@@ -4,23 +4,23 @@
 modname = 'rememberme'
 distname = 'cubicweb-rememberme'
 
-numversion = (0, 1, 3)
+numversion = (0, 2, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
-
+description = 'implementation of the Remember Me feature for the CubicWeb framework'
 author = 'LOGILAB S.A. (Paris, FRANCE)'
 author_email = 'contact@logilab.fr'
 web = 'http://www.cubicweb.org/project/%s' % distname
 
-short_desc = 'implementation of the Remember Me feature for the CubicWeb framework'
 
-__depends__ = {'cubicweb': '>= 3.8.0'}
-__recommends__ = {}
+__depends__ = {'cubicweb': '>= 3.9.0'}
 
 
+# packaging ###
+
 from os import listdir as _listdir
-from os.path import join, isdir, exists, dirname
+from os.path import join, isdir
 from glob import glob
 
 THIS_CUBE_DIR = join('share', 'cubicweb', 'cubes', modname)
@@ -36,9 +36,8 @@ data_files = [
     [THIS_CUBE_DIR, [fname for fname in glob('*.py') if fname != 'setup.py']],
     ]
 # check for possible extended cube layout
-for dirname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'i18n', 'migration'):
+for dirname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'i18n', 'migration', 'wdoc'):
     if isdir(dirname):
         data_files.append([join(THIS_CUBE_DIR, dirname), listdir(dirname)])
 # Note: here, you'll need to add subdirectories if you want
 # them to be included in the debian package
-
