@@ -8,7 +8,7 @@
 from datetime import date, timedelta
 from random import randint
 
-from cubicweb.selectors import implements
+from cubicweb.selectors import is_instance
 from cubicweb.web import uicfg, formfields as ff, formwidgets as fw
 from cubicweb.web.views import (authentication, basecontrollers, basetemplates,
                                 autoform, actions)
@@ -45,11 +45,10 @@ class AuthCookieRetreiver(authentication.WebAuthInfoRetreiver):
         except KeyError:
             raise authentication.NoAuthInfo()
         try:
-            login, magic = authcookie.split(';__magic=', 1)
+            login, magic = authcookie.split('|__magic=', 1)
         except ValueError:
             req.remove_cookie(cookie, '__cw_auth_cookie')
             raise authentication.NoAuthInfo()
-        print login, {'magicnumber': magic}
         return login, {'magicnumber': magic}
 
     def authenticated(self, retreiver, req, cnx, login, authinfo):
@@ -75,16 +74,34 @@ class AuthCookieRetreiver(authentication.WebAuthInfoRetreiver):
         cnx.commit()
         magicnum = authentity.magicnumber
         cookie = req.get_cookie()
-        cookie['__cw_auth_cookie'] = '%s;__magic=%s' % (user.login, magicnum)
+        cookie['__cw_auth_cookie'] = '%s|__magic=%s' % (user.login, magicnum)
         req.set_cookie(cookie, '__cw_auth_cookie', maxage=None,
                        expires=date.today() + self.cookie_lifetime)
         authinfo['magicnumber'] = magicnum
 
+    def request_has_auth_info(self, req):
+        cookie = req.get_cookie()
+        try:
+            authcookie = cookie['__cw_auth_cookie'].value
+        except KeyError:
+            return False
+        try:
+            authcookie.split('|__magic=', 1)
+        except ValueError:
+            req.remove_cookie(cookie, '__cw_auth_cookie')
+            return False
+        return True
+
+    def revalidate_login(self):
+        cookie = self._cw.get_cookie()
+        authcookie = cookie['__cw_auth_cookie'].value
+        return authcookie.split('|__magic=', 1)[0]
+
 
 # add remember me checkbox on the login form ###################################
 
 basetemplates.LogForm.append_field(
-    ff.BooleanField('__setauthcookie', choices=[(_('remember me'), True)],
+    ff.BooleanField('__setauthcookie', choices=[(_('remember me'), u'1')],
                     label=None, widget=fw.CheckBox({'class': 'data'}))
     )
 
@@ -92,12 +109,12 @@ basetemplates.LogForm.append_field(
 # deactivate manual addition/edition ###########################################
 
 class UneditableCWAuthCookieEdition(autoform.AutomaticEntityForm):
-    __select__ = implements('CWAuthCookie')
+    __select__ = is_instance('CWAuthCookie')
     def __init__(self, *args, **kwargs):
         raise Unauthorized()
 
-actions.ModifyAction.__select__ = actions.ModifyAction.__select__ & ~implements('CWAuthCookie')
-actions.MultipleEditAction.__select__ = actions.MultipleEditAction.__select__ & ~implements('CWAuthCookie')
+actions.ModifyAction.__select__ = actions.ModifyAction.__select__ & ~is_instance('CWAuthCookie')
+actions.MultipleEditAction.__select__ = actions.MultipleEditAction.__select__ & ~is_instance('CWAuthCookie')
 
 
 
